<?php

namespace jrosset\ArrayClasses;

use OutOfRangeException;

trait TInternalArray {
    /**
     * Create or replace a cell value
     *
     * @param mixed $cellName  The cell name/offset
     * @param mixed $cellValue The cell new value
     *
     * @return $this
     */
    public function set ($cellName, $cellValue): self {
        $this->array[$cellName] = $cellValue;
        return $this;
    }
    /**
     * Remove a cell
     *
     * @param mixed     $cellName                    The cell name/offset
     * @param bool|null $throwsForNonExistentElement If set, temporarily override {@see ImmutableArrayClass::$throwsForNonExistentElement}
     *
     * @return $this
     */
    public function del ($cellName, ?bool $throwsForNonExistentElement = null): self {
        if ($throwsForNonExistentElement ?? $this->throwsForNonExistentElement() && !$this->has($cellName)) {
            throw new OutOfRangeException();
        }
        unset($this->array[$cellName]);

        return $this;
    }

    /**
     * @inheritDoc
     */
    public function offsetSet ($offset, $value): void {
        $this->set($offset, $value);
    }
    /**
     * @inheritDoc
     */
    public function offsetUnset ($offset): void {
        $this->del($offset);
    }
}